@@ -239,7 +239,7 @@ create_font_frame(struct font_prm *prm)
 #else
   hbox = gtk_hbox_new(FALSE, 4);
 #endif
-  gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 4);
+  gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 4);
 
 #if GTK_CHECK_VERSION(3, 0, 0)
   vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
