@@ -129,6 +129,7 @@ loaddatalist(struct file_prm *prm, const char *datalist)
     }
     for (j = 0; j < i; j++) {
       if ((g_strcmp0(prm->data[i].file, prm->data[j].file) == 0) &&
+	  (prm->data[i].show == prm->data[j].show) &&
 	  (prm->data[i].x == prm->data[j].x) &&
 	  (prm->data[i].y == prm->data[j].y) &&
 	  (g_strcmp0(prm->data[i].math_x, prm->data[j].math_x) == 0) &&
@@ -285,7 +286,7 @@ savescript(struct file_prm *prm)
   gy = posy;
 
   for (i = 0; i < prm->file_num; i++) {
-    if ((( prm->data[i].mix == -1) || (! mix )) && prm->data[i].show) {
+    if (((prm->data[i].mix == -1) || (! mix )) && prm->data[i].show) {
       gx = posx;
       if (type) {
         makescript(f, &prm->data[i], gx, gy, width, height);
@@ -545,11 +546,9 @@ create_file_frame(struct file_prm *prm)
 
   list = gtk_list_store_new(n + 1, G_TYPE_BOOLEAN, G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_STRING);
   tview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(list));
-  gtk_widget_set_size_request(GTK_WIDGET(tview), -1, 200);
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tview), TRUE);
   gtk_tree_view_set_grid_lines(GTK_TREE_VIEW(tview), GTK_TREE_VIEW_GRID_LINES_VERTICAL);
 
-
   renderer = gtk_cell_renderer_toggle_new();
   col = gtk_tree_view_column_new_with_attributes("", renderer, "active", 0, NULL);
   g_object_set(renderer, "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE, NULL);
@@ -558,7 +557,7 @@ create_file_frame(struct file_prm *prm)
 
   for (i = 0; i < n; i++) {
     renderer = gtk_cell_renderer_text_new();
-    col = gtk_tree_view_column_new_with_attributes(title[i], renderer, "text", i + 1, NULL);
+    col = gtk_tree_view_column_new_with_attributes(title[i], renderer, "text", i + 1, "sensitive", 0, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(tview), col);
   }
   g_object_set(renderer, "editable", TRUE, NULL);
@@ -567,6 +566,7 @@ create_file_frame(struct file_prm *prm)
   swin = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_container_add(GTK_CONTAINER(swin), tview);
+  gtk_widget_set_size_request(GTK_WIDGET(swin), -1, 300);
 
   frame = gtk_frame_new(NULL);
   gtk_container_add(GTK_CONTAINER(frame), swin);
@@ -594,10 +594,10 @@ create_control(GtkWidget *box, struct file_prm *prm)
   hbox = gtk_hbox_new(FALSE, 4);
 #endif
   w = create_option_frame(prm);
-  gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 4);
+  gtk_box_pack_start(GTK_BOX(hbox), w, TRUE, TRUE, 4);
 
   w = create_geometry_frame(prm);
-  gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 4);
+  gtk_box_pack_start(GTK_BOX(hbox), w, TRUE, TRUE, 4);
 
   w = create_font_frame(&prm->font);
   gtk_box_pack_start(GTK_BOX(hbox), w, TRUE, TRUE, 4);
@@ -630,13 +630,19 @@ get_opt(int argc, char **argv, struct file_prm *prm)
   for (i = 1; i < argc; i++) {
     if (strcmp(argv[i], "-x") == 0) {
       i++;
-      prm->posx = atoi(argv[i]);
+      if (argv[i]) {
+	prm->posx = atoi(argv[i]);
+      }
     } else if (strcmp(argv[i], "-y") == 0) {
       i++;
-      prm->posy = atoi(argv[i]);
+      if (argv[i]) {
+	prm->posy = atoi(argv[i]);
+      }
     } else if (strcmp(argv[i], "-w") == 0) {
       i++;
-      prm->w = atoi(argv[i]);
+      if (argv[i]) {
+	prm->w = atoi(argv[i]);
+      }
     } else if (data_file == NULL) {
       data_file = argv[i];
     } else {
