@@ -24,7 +24,9 @@
 
 #ifdef __MINGW32__
 #define WINDOWS 1
+#ifndef _WIN32_WINNT
 #define _WIN32_WINNT 0x0500
+#endif
 #include <windows.h>
 #endif
 
@@ -40,4 +42,13 @@
 
 #define USE_MEM_PROFILE 0
 
+#define MARK_TYPE_NUM 90
+
+int printfconsole(char *fmt,...);
+int putconsole(const char *s);
+int printfconsole(char *fmt,...);
+void displaydialog(const char *str);
+void displaystatus(const char *str);
+void pausewindowconsole(char *title,char *str);
+
 #endif	/* COMMON_HEADER */
