@@ -4,19 +4,50 @@
 
 #include <stdlib.h>
 
-#include "gtk_common.h"
+#include "gra.h"
 
+#include "gtk_common.h"
 #include "gtk_liststore.h"
 
-GtkWidget *
-create_object_cbox(void)
-{
-  GtkTreeModel *model;
-  GtkCellRenderer *rend;
-  GtkWidget *cbox;
+#include "x11dialg.h"
 
-  model = GTK_TREE_MODEL(gtk_tree_store_new(3, G_TYPE_STRING, G_TYPE_OBJECT, G_TYPE_INT));
-  cbox = gtk_combo_box_new_with_model(model);
+
+static gboolean
+combo_box_separator_func(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
+{
+  char *str;
+  int r;
+
+  gtk_tree_model_get(model, iter, OBJECT_COLUMN_TYPE_STRING, &str, -1);
+  r = ! str;
+
+  if (str) {
+    g_free(str);
+  }
+
+  return r;
+}
+
+void
+init_object_combo_box(GtkWidget *cbox)
+{
+  GtkCellRenderer *rend;
+  GtkTreeViewRowSeparatorFunc func;
+
+  func = gtk_combo_box_get_row_separator_func(GTK_COMBO_BOX(cbox));
+  if (func == NULL) {
+    gtk_combo_box_set_row_separator_func(GTK_COMBO_BOX(cbox), combo_box_separator_func, NULL, NULL);
+  }
+
+  gtk_cell_layout_clear(GTK_CELL_LAYOUT(cbox));
+
+  rend = gtk_cell_renderer_toggle_new();
+  gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(cbox), rend, FALSE);
+  gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(cbox), rend,
+				 "active", OBJECT_COLUMN_TYPE_TOGGLE,
+				 "visible", OBJECT_COLUMN_TYPE_TOGGLE_VISIBLE,
+				 "radio", OBJECT_COLUMN_TYPE_TOGGLE_IS_RADIO,
+				 NULL);
 
   rend = gtk_cell_renderer_text_new();
   gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(cbox), rend, FALSE);
@@ -25,13 +56,178 @@ create_object_cbox(void)
   rend = gtk_cell_renderer_pixbuf_new();
   gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(cbox), rend, FALSE);
   gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(cbox), rend, "pixbuf", OBJECT_COLUMN_TYPE_PIXBUF);
+}
 
+static GtkTreeModel *
+create_object_tree_model(void)
+{
+  return GTK_TREE_MODEL(gtk_tree_store_new(OBJECT_COLUMN_TYPE_NUM, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_OBJECT, G_TYPE_INT, G_TYPE_INT, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN));
+}
 
+static GtkWidget *
+create_object_cbox(void)
+{
+  GtkTreeModel *model;
+  GtkWidget *cbox;
+
+  model = create_object_tree_model();
+  cbox = gtk_combo_box_new_with_model(model);
+
+  init_object_combo_box(cbox);
   g_object_set(cbox, "has-frame", FALSE, NULL);
 
   return cbox;
 }
 
+void
+add_separator_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent)
+{
+  add_text_combo_item_to_cbox(list, iter, parent, -1, -1, NULL, TOGGLE_NONE, FALSE);
+}
+
+void
+add_font_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id)
+{
+  struct fontmap *fcur;
+  char *font;
+  int match;
+
+  getobj(obj, field, id, 0, NULL, &font);
+
+  fcur = Gra2cairoConf->fontmap_list_root;
+  while (fcur) {
+    match = ! g_strcmp0(font, fcur->fontalias);
+    add_text_combo_item_to_cbox(list, iter, parent, column_id, -1, fcur->fontalias, TOGGLE_RADIO, match);
+    fcur = fcur->next;
+  }
+}
+
+void
+add_font_style_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id_bold, int column_id_italic, struct objlist *obj, const char *field, int id)
+{
+  int style;
+
+  getobj(obj, field, id, 0, NULL, &style);
+
+  add_text_combo_item_to_cbox(list, iter, parent, column_id_bold, -1, _("Bold"), TOGGLE_CHECK, style & GRA_FONT_STYLE_BOLD);
+  add_text_combo_item_to_cbox(list, iter, parent, column_id_italic, -1, _("Italic"), TOGGLE_CHECK, style & GRA_FONT_STYLE_ITALIC);
+}
+
+void
+add_text_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, int enum_id, const char *title, enum TOGGLE_TYPE type, int active)
+{
+  GtkTreeIter locl_iter;
+
+  if (iter == NULL) {
+    iter = &locl_iter;
+  }
+
+  gtk_tree_store_append(list, iter, parent);
+  gtk_tree_store_set(list, iter,
+		     OBJECT_COLUMN_TYPE_STRING, title,
+		     OBJECT_COLUMN_TYPE_PIXBUF, NULL,
+		     OBJECT_COLUMN_TYPE_INT, column_id,
+		     OBJECT_COLUMN_TYPE_TOGGLE_VISIBLE, type != TOGGLE_NONE,
+		     OBJECT_COLUMN_TYPE_TOGGLE_IS_RADIO, type == TOGGLE_RADIO,
+		     OBJECT_COLUMN_TYPE_TOGGLE, active,
+		     OBJECT_COLUMN_TYPE_PIXBUF_VISIBLE, FALSE,
+		     OBJECT_COLUMN_TYPE_ENUM, enum_id,
+		     -1);
+}
+
+void
+add_mark_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id)
+{
+  int j, type;
+  GtkTreeIter locl_iter;
+
+  if (iter == NULL) {
+    iter = &locl_iter;
+  }
+
+  type = -1;
+  getobj(obj, field, id, 0, NULL, &type);
+
+
+  for (j = 0; j < MARK_TYPE_NUM; j++) {
+    GdkPixbuf *pixbuf;
+#if GTK_CHECK_VERSION(3, 0, 0)
+    pixbuf = gdk_pixbuf_get_from_surface(NgraphApp.markpix[j],
+					 0, 0, MARK_PIX_SIZE, MARK_PIX_SIZE);
+#else
+    pixbuf = gdk_pixbuf_get_from_drawable(NULL, NgraphApp.markpix[j], NULL, 0, 0, 0, 0, -1, -1);
+#endif
+    if (pixbuf) {
+      char buf[64];
+
+      gtk_tree_store_append(list, iter, parent);
+      snprintf(buf, sizeof(buf), "%02d ", j);
+      gtk_tree_store_set(list, iter,
+			 OBJECT_COLUMN_TYPE_STRING, buf,
+			 OBJECT_COLUMN_TYPE_PIXBUF, pixbuf,
+			 OBJECT_COLUMN_TYPE_INT, column_id,
+			 OBJECT_COLUMN_TYPE_TOGGLE_VISIBLE, TRUE,
+			 OBJECT_COLUMN_TYPE_TOGGLE_IS_RADIO, TRUE,
+			 OBJECT_COLUMN_TYPE_TOGGLE, j == type,
+			 OBJECT_COLUMN_TYPE_ENUM, j,
+			 -1);
+      g_object_unref(pixbuf);
+    }
+  }
+}
+
+void
+add_enum_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id)
+{
+  char **enum_array;
+  int state, i;
+
+  getobj(obj, field, id, 0, NULL, &state);
+  enum_array = (char **) chkobjarglist(obj, field);
+  if (enum_array == NULL) {
+    return;
+  }
+
+  for (i = 0; enum_array[i] && enum_array[i][0]; i++) {
+    add_text_combo_item_to_cbox(list, iter, parent, column_id, i, _(enum_array[i]), TOGGLE_RADIO, i == state);
+  }
+}
+
+void
+add_bool_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id, const char *title)
+{
+  GtkTreeIter locl_iter;
+  int state;
+
+  if (iter == NULL) {
+    iter = &locl_iter;
+  }
+
+  getobj(obj, field, id, 0, NULL, &state);
+
+  add_text_combo_item_to_cbox(list, iter, parent, column_id, -1, title, TOGGLE_CHECK, state);
+}
+
+void
+add_line_style_item_to_cbox(GtkTreeStore *list, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id)
+{
+  GtkTreeIter iter;
+  int i, active;
+  char *str;
+
+  sgetobjfield(obj, id, field, NULL, &str, FALSE, FALSE, FALSE);
+  if (str == NULL) {
+    return;
+  }
+
+  add_text_combo_item_to_cbox(list, &iter, parent, -1, -1, _("Line style"), TOGGLE_NONE, FALSE);
+  for (i = 0; FwLineStyle[i].name; i++) {
+    active = ! strcmp(str, FwLineStyle[i].list);
+    add_text_combo_item_to_cbox(list, NULL, &iter, column_id, i, _(FwLineStyle[i].name), TOGGLE_RADIO, active);
+  }
+  g_free(str);
+}
+
 GtkCellEditable *
 #if GTK_CHECK_VERSION(3, 0, 0)
 start_editing_obj(GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path,
@@ -45,7 +241,7 @@ start_editing_obj(GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, con
 }
 
 static GtkTreeViewColumn *
-create_column(n_list_store *list, int i, int j)
+create_column(n_list_store *list, int i)
 {
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *col;
@@ -54,10 +250,11 @@ create_column(n_list_store *list, int i, int j)
   switch (list[i].type) {
   case G_TYPE_BOOLEAN:
     renderer = gtk_cell_renderer_toggle_new();
-    col = gtk_tree_view_column_new_with_attributes(list[i].title, renderer,
+    col = gtk_tree_view_column_new_with_attributes(_(list[i].title), renderer,
 						   "active", i, NULL);
     if (list[i].editable) {
       g_object_set(renderer, "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE, NULL);
+      g_object_set_data(G_OBJECT(renderer), "user-data", &list[i]);
     }
     break;
   case G_TYPE_INT:
@@ -68,7 +265,11 @@ create_column(n_list_store *list, int i, int j)
   case G_TYPE_UINT64:
   case G_TYPE_FLOAT:
   case G_TYPE_DOUBLE:
+#if GTK_CHECK_VERSION(3, 8, 0) || ! GTK_CHECK_VERSION(3, 0, 0)
     renderer = gtk_cell_renderer_spin_new();
+#else
+    renderer = gtk_cell_renderer_text_new();
+#endif
     col = gtk_tree_view_column_new_with_attributes(_(list[i].title), renderer,
 						   "text", i, NULL);
     gtk_tree_view_column_set_resizable(col, TRUE);
@@ -77,6 +278,7 @@ create_column(n_list_store *list, int i, int j)
       if (list[i].type == G_TYPE_DOUBLE || list[i].type == G_TYPE_FLOAT) {
 	g_object_set((GObject *) renderer,
 		     "editable", list[i].editable,
+#if GTK_CHECK_VERSION(3, 8, 0) || ! GTK_CHECK_VERSION(3, 0, 0)
 		     "adjustment", gtk_adjustment_new(0,
 						      list[i].min / 100.0,
 						      list[i].max / 100.0,
@@ -84,11 +286,13 @@ create_column(n_list_store *list, int i, int j)
 						      list[i].page / 100.0,
 						      0),
 		     "digits", 2,
+#endif
 		     NULL);
 	g_object_set_data(G_OBJECT(renderer), "user-data", &list[i]);
       } else {
 	g_object_set((GObject *) renderer,
 		     "editable", list[i].editable,
+#if GTK_CHECK_VERSION(3, 8, 0) || ! GTK_CHECK_VERSION(3, 0, 0)
 		     "adjustment", gtk_adjustment_new(0,
 						      list[i].min,
 						      list[i].max,
@@ -96,11 +300,15 @@ create_column(n_list_store *list, int i, int j)
 						      list[i].page,
 						      0),
 		     "digits", 0,
+#endif
 		     NULL);
 	g_object_set_data(G_OBJECT(renderer), "user-data", &list[i]);
 
       }
     }
+    if (list[i].editable) {
+      gtk_tree_view_column_set_expand(col, TRUE);
+    }
     break;
   case G_TYPE_OBJECT:
     renderer = gtk_cell_renderer_pixbuf_new();
@@ -115,6 +323,19 @@ create_column(n_list_store *list, int i, int j)
     col = gtk_tree_view_column_new_with_attributes(_(list[i].title), renderer,
 						   "pixbuf", i, NULL);
     break;
+  case G_TYPE_PARAM:
+    renderer = gtk_cell_renderer_combo_new();
+    model = create_object_tree_model();
+    g_object_set((GObject *) renderer,
+		 "has-entry", FALSE,
+		 "model", model,
+		 "text-column", OBJECT_COLUMN_TYPE_STRING,
+		 "editable", list[i].editable,
+		 NULL);
+    g_object_set_data(G_OBJECT(renderer), "user-data", &list[i]);
+    col = gtk_tree_view_column_new_with_attributes(_(list[i].title), renderer,
+						   "text", i, NULL);
+    break;
   case G_TYPE_ENUM:
     renderer = gtk_cell_renderer_combo_new();
     model = GTK_TREE_MODEL(gtk_list_store_new(1, G_TYPE_STRING));
@@ -134,21 +355,14 @@ create_column(n_list_store *list, int i, int j)
     g_object_set((GObject *) renderer,
 		 "editable", list[i].editable,
 		 "ellipsize", list[i].ellipsize,
-		 "ellipsize-set", list[i].ellipsize != PANGO_ELLIPSIZE_NONE,
 		 NULL);
     g_object_set_data(G_OBJECT(renderer), "user-data", &list[i]);
-    if (list[i].color){
-      col = gtk_tree_view_column_new_with_attributes(_(list[i].title), renderer,
-						     "text", i,
-						     "foreground", j,
-						     NULL);
-    } else {
-      col = gtk_tree_view_column_new_with_attributes(_(list[i].title), renderer,
+    col = gtk_tree_view_column_new_with_attributes(_(list[i].title), renderer,
 						     "text", i, NULL);
-    }
     gtk_tree_view_column_set_resizable(col, TRUE);
-    if (list[i].ellipsize != PANGO_ELLIPSIZE_NONE)
+    if (list[i].ellipsize != PANGO_ELLIPSIZE_NONE || list[i].editable) {
       gtk_tree_view_column_set_expand(col, TRUE);
+    }
   }
   return col;
 }
@@ -179,27 +393,20 @@ create_tree_view(int n, n_list_store *list, int tree)
 {
   GType *tarray;
   GtkTreeModel *lstore;
-  GtkCellRenderer *renderer;
   GtkWidget *tview;
   GtkTreeViewColumn *col;
   GtkTreeSelection *sel;
-  int i, j, cnum = 0;
+  int i;
 
   if (n < 1 || list == NULL)
     return NULL;
 
-  for (i = 0; i < n; i++) {
-    if (list[i].color) {
-      cnum++;
-    }
-  }
-
-  tarray = g_malloc(sizeof(*tarray) * (n + cnum));
+  tarray = g_malloc(sizeof(*tarray) * n);
   if (tarray == NULL)
     return NULL;
 
   for (i = 0; i < n; i++) {
-    if (list[i].type == G_TYPE_DOUBLE || list[i].type == G_TYPE_ENUM) {
+    if (list[i].type == G_TYPE_DOUBLE || list[i].type == G_TYPE_ENUM || list[i].type == G_TYPE_PARAM) {
       tarray[i] = G_TYPE_STRING;
     } else {
       tarray[i] = list[i].type;
@@ -207,15 +414,10 @@ create_tree_view(int n, n_list_store *list, int tree)
     list[i].edited_id = 0;
   }
 
-  for (i = 0; i < cnum; i++) {
-    tarray[i + n] = G_TYPE_STRING;
-    list[i].edited_id = 0;
-  }
-
   if (tree) {
-    lstore = GTK_TREE_MODEL(gtk_tree_store_newv(n + cnum, tarray));
+    lstore = GTK_TREE_MODEL(gtk_tree_store_newv(n, tarray));
   } else {
-    lstore = GTK_TREE_MODEL(gtk_list_store_newv(n + cnum, tarray));
+    lstore = GTK_TREE_MODEL(gtk_list_store_newv(n, tarray));
   }
   g_free(tarray);
 
@@ -228,25 +430,15 @@ create_tree_view(int n, n_list_store *list, int tree)
   sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(tview));
   gtk_tree_selection_set_mode(sel, GTK_SELECTION_SINGLE);
 
-  j = 0;
   for (i = 0; i < n; i++) {
-    col = create_column(list, i, j + n);
-    if (list[i].color){
-      j++;
+    if (list[i].visible) {
+      col = create_column(list, i);
+      gtk_tree_view_column_set_visible(col, list[i].visible);
+      gtk_tree_view_append_column(GTK_TREE_VIEW(tview), col);
     }
-    gtk_tree_view_column_set_visible(col, list[i].visible);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(tview), col);
   }
 
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tview), n > 1);
-  for (i = 0; i < cnum; i++) {
-    renderer = gtk_cell_renderer_text_new();
-    col = gtk_tree_view_column_new_with_attributes("color", renderer,
-						   "text", i + n,
-						   NULL);
-    gtk_tree_view_column_set_visible(col, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(tview), col);
-  }
 
   return tview;
 }
@@ -902,3 +1094,22 @@ tree_store_selected_toggle_expand(GtkWidget *w)
     gtk_tree_view_expand_row(GTK_TREE_VIEW(w), path, FALSE);
   }
 }
+
+
+int
+tree_view_get_selected_row_int_from_path(GtkWidget *view, gchar *path, GtkTreeIter *iter, int col)
+{
+  GtkTreeModel *model;
+  int sel;
+
+  model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
+  if (! gtk_tree_model_get_iter_from_string(model, iter, path)) {
+    return -1;
+  }
+
+
+  list_store_select_iter(GTK_WIDGET(view), iter);
+  gtk_tree_model_get(model, iter, col, &sel, -1);
+
+  return sel;
+}
