@@ -5,22 +5,46 @@
 #ifndef _GTK_LISTSTORE_HEADER
 #define _GTK_LISTSTORE_HEADER
 
-#define OBJECT_COLUMN_TYPE_STRING 0
-#define OBJECT_COLUMN_TYPE_PIXBUF 1
-#define OBJECT_COLUMN_TYPE_INT    2
+#include "object.h"
+
+enum TOGGLE_TYPE {
+  TOGGLE_NONE,
+  TOGGLE_CHECK,
+  TOGGLE_RADIO,
+};
+
+enum OBJECT_COLUMN_TYPE {
+  OBJECT_COLUMN_TYPE_TOGGLE,
+  OBJECT_COLUMN_TYPE_STRING,
+  OBJECT_COLUMN_TYPE_PIXBUF,
+  OBJECT_COLUMN_TYPE_INT,
+  OBJECT_COLUMN_TYPE_ENUM,
+  OBJECT_COLUMN_TYPE_TOGGLE_VISIBLE,
+  OBJECT_COLUMN_TYPE_TOGGLE_IS_RADIO,
+  OBJECT_COLUMN_TYPE_PIXBUF_VISIBLE,
+  OBJECT_COLUMN_TYPE_NUM,
+};
 
 typedef struct _list_store {
   char *title;
   GType type;
   gboolean visible, editable;
   char *name;
-  gboolean color;
   int min, max, inc, page;
   PangoEllipsizeMode ellipsize;
   gulong edited_id;
 } n_list_store;
 
-GtkWidget *create_object_cbox(void);
+void init_object_combo_box(GtkWidget *cbox);
+
+void add_separator_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent);
+void add_line_style_item_to_cbox(GtkTreeStore *list, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id);
+void add_bool_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id, const char *title);
+void add_mark_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id);
+void add_enum_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id);
+void add_font_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, struct objlist *obj, const char *field, int id);
+void add_text_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id, int enum_id, const char *title, enum TOGGLE_TYPE type, int active);
+void add_font_style_combo_item_to_cbox(GtkTreeStore *list, GtkTreeIter *iter, GtkTreeIter *parent, int column_id_bold, int column_id_italic, struct objlist *obj, const char *field, int id);
 
 GtkWidget *list_store_create(int n, n_list_store *list);
 
@@ -79,6 +103,8 @@ void free_tree_path_cb(gpointer data, gpointer user_data);
 
 void tree_store_selected_toggle_expand(GtkWidget *w);
 
+int tree_view_get_selected_row_int_from_path(GtkWidget *view, gchar *path, GtkTreeIter *iter, int col);
+
 #define tree_store_get_int		list_store_get_int
 #define tree_store_get_boolean		list_store_get_boolean
 #define tree_store_get_string		list_store_get_string
