@@ -11,6 +11,57 @@
 #include "x11menu.h"
 #include "x11gui.h"
 
+void
+set_widget_margin(GtkWidget *w, int margin_pos)
+{
+#if GTK_CHECK_VERSION(3, 0, 0)
+  if (margin_pos & WIDGET_MARGIN_LEFT) {
+    gtk_widget_set_margin_left(w, 4);
+  }
+
+  if (margin_pos & WIDGET_MARGIN_RIGHT) {
+    gtk_widget_set_margin_right(w, 4);
+  }
+
+  if (margin_pos & WIDGET_MARGIN_BOTTOM) {
+    gtk_widget_set_margin_bottom(w, 4);
+  }
+
+  if (margin_pos & WIDGET_MARGIN_TOP) {
+    gtk_widget_set_margin_top(w, 4);
+  }
+#endif
+}
+
+void
+set_scale_mark(GtkWidget *scale, GtkPositionType pos, int start, int inc)
+{
+  int max, val;
+  GtkAdjustment *adj;
+
+  adj = gtk_range_get_adjustment(GTK_RANGE(scale));
+  max = gtk_adjustment_get_upper(adj);
+
+  for (val = start; val <=max; val += inc) {
+    gtk_scale_add_mark(GTK_SCALE(scale), val, pos, NULL);
+  }
+
+  switch (pos) {
+  case GTK_POS_BOTTOM:
+    gtk_scale_set_value_pos(GTK_SCALE(scale), GTK_POS_TOP);
+    break;
+  case GTK_POS_TOP:
+    gtk_scale_set_value_pos(GTK_SCALE(scale), GTK_POS_BOTTOM);
+    break;
+  case GTK_POS_LEFT:
+    gtk_scale_set_value_pos(GTK_SCALE(scale), GTK_POS_RIGHT);
+    break;
+  case GTK_POS_RIGHT:
+    gtk_scale_set_value_pos(GTK_SCALE(scale), GTK_POS_LEFT);
+    break;
+  }
+}
+
 GtkWidget *
 get_mnemonic_label(GtkWidget *w)
 {
@@ -58,6 +109,31 @@ set_widget_sensitivity_with_label(GtkWidget *w, gboolean state)
   }
 }
 
+void
+set_widget_visibility_with_label(GtkWidget *w, gboolean state)
+{
+  GtkWidget *label;
+
+  if(w == NULL) {
+    return;
+  }
+
+  if (G_TYPE_CHECK_INSTANCE_TYPE(w, GTK_TYPE_LABEL)) {
+    label = w;
+    w = gtk_label_get_mnemonic_widget(GTK_LABEL(w));
+  } else {
+    label = get_mnemonic_label(w);
+  }
+
+  if (w) {
+    gtk_widget_set_visible(w, state);
+  }
+
+  if (label) {
+    gtk_widget_set_visible(label, state);
+  }
+}
+
 GtkWidget *
 add_widget_to_table_sub(GtkWidget *table, GtkWidget *w, char *title, int expand, int col, int width, int col_max, int n)
 {
@@ -768,11 +844,7 @@ set_scroll_visibility(GtkWidget *scroll)
   max = gtk_adjustment_get_upper(adj);
   page = gtk_adjustment_get_page_size(adj);
 
-  if (max - min > page) {
-    gtk_widget_show(scroll);
-  } else {
-    gtk_widget_hide(scroll);
-  }
+  gtk_widget_set_visible(scroll, max - min > page);
 }
 
 static void
