@@ -41,11 +41,10 @@
 #ifdef LOCALEDIR
 #undef LOCALEDIR
 #endif	/* LOCALEDIR */
-char *DOCDIR, *NDATADIR, *ADDINDIR, *LIBDIR, *CONFDIR, *LOCALEDIR, *PIXMAPDIR;
+char *DOCDIR, *NDATADIR, *ADDINDIR, *LIBDIR, *PLUGINDIR, *CONFDIR, *LOCALEDIR, *PIXMAPDIR;
 #endif	/* WINDOWS */
 
 #include "dir_defs.h"
-#include "ngraph.h"
 #include "object.h"
 #include "ioutil.h"
 #include "nstring.h"
@@ -107,6 +106,7 @@ void *addaxis(void);
 void *addagrid(void);
 void *addprm(void);
 void *addpath(void);
+void *addplugin(void);
 
 void *addgra2gtk(void);
 void *addmenu(void);
@@ -193,6 +193,7 @@ static void * ( * obj_add_func_ary[]) (void) = {
   addtext,
   addmenu,
   adddialog,
+  addplugin,
 #ifdef WINDOWS
   addgra2emf,
 #endif
@@ -707,6 +708,7 @@ set_dir_defs(char *app)
 
   DOCDIR = g_strdup_printf("%s%c%s", app_path, DIRSEP, "doc");
   LIBDIR = g_strdup_printf("%s%c%s", app_path, DIRSEP, "bin");
+  PLUGINDIR = g_strdup_printf("%s%c%s", app_path, DIRSEP, "lib/plugins");
   NDATADIR = g_strdup_printf("%s%c%s", app_path, DIRSEP, "share");
   ADDINDIR = g_strdup_printf("%s%c%s", app_path, DIRSEP, "share/addin");
   CONFDIR = g_strdup_printf("%s%c%s", app_path, DIRSEP, "etc");
@@ -747,7 +749,7 @@ n_getlocale(void)
 int
 main(int argc, char **argv)
 {
-  char *homedir, *datadir, *docdir, *libdir, *confdir, *inifile, *loginshell;
+  char *homedir, *datadir, *docdir, *libdir, *plugindir, *confdir, *inifile, *loginshell;
   const char *home;
   N_VALUE *inst;
   struct objlist *sys, *obj, *lobj;
@@ -820,6 +822,10 @@ main(int argc, char **argv)
   if (libdir == NULL)
     exit(1);
 
+  plugindir = g_strdup(PLUGINDIR);
+  if (plugindir == NULL)
+    exit(1);
+
   docdir = g_strdup(DOCDIR);
   if (docdir == NULL)
     exit(1);
@@ -883,6 +889,8 @@ main(int argc, char **argv)
     exit(1);
   if (_putobj(sys, "lib_dir", inst, libdir))
     exit(1);
+  if (_putobj(sys, "plugin_dir", inst, plugindir))
+    exit(1);
   if (_putobj(sys, "home_dir", inst, homedir))
     exit(1);
 
@@ -894,6 +902,8 @@ main(int argc, char **argv)
     exit(1);
   if (_getobj(sys, "lib_dir", inst, &libdir) == -1)
     exit(1);
+  if (_getobj(sys, "plugin_dir", inst, &plugindir) == -1)
+    exit(1);
   if (_getobj(sys, "home_dir", inst, &homedir) == -1)
     exit(1);
 
@@ -1485,7 +1495,7 @@ get_file_list(const char *path, int type, int mode)
 {
   GDir *dir;
   const char *ent;
-  struct stat statbuf;
+  GStatBuf statbuf;
   struct mylist *list = NULL, *list_next = list;
   char *full_path_name;
 
