@@ -33,7 +33,6 @@
 
 #include "strconv.h"
 
-#include "ngraph.h"
 #include "object.h"
 #include "ioutil.h"
 #include "gra.h"
@@ -195,7 +194,7 @@ gtkclose(GtkWidget *widget, GdkEvent *event, gpointer user_data)
       break;
     }
   }
-  return FALSE;
+  return TRUE;
 }
 
 static gboolean
@@ -975,7 +974,7 @@ static struct objtable gra2gtk[] = {
   {"flush", NVFUNC, NREAD | NEXEC, gtkflush, "", 0},
   {"clear", NVFUNC, NREAD | NEXEC, gtkclear, "", 0},
   {"present", NVFUNC, NREAD | NEXEC, gtkpresent, "", 0},
-  {"fullscreen", NVFUNC, NREAD | NEXEC, gtkfullscreen, "i", 0},
+  {"fullscreen", NVFUNC, NREAD | NEXEC, gtkfullscreen, "b", 0},
   {"BR", NINT, NREAD | NWRITE, gtkbr, NULL, 0},
   {"BG", NINT, NREAD | NWRITE, gtkbg, NULL, 0},
   {"BB", NINT, NREAD | NWRITE, gtkbb, NULL, 0},
