@@ -38,15 +38,6 @@
 extern int Globallock;
 extern struct savedstdio GtkIOSave;
 
-extern void mgtkdisplaydialog(const char *str);
-extern void mgtkdisplaystatus(const char *str);
-extern int mgtkputstderr(const char *s);
-extern int mgtkprintfstderr(char *fmt, ...);
-extern int mgtkputstdout(const char *s);
-extern int mgtkprintfstdout(char *fmt, ...);
-extern int mgtkinterrupt(void);
-extern int mgtkinputyn(const char *mes);
-
 enum paper_id {
   PAPER_ID_A3,
   PAPER_ID_A4,
@@ -109,7 +100,6 @@ struct menulocal
   N_VALUE *inst;
   struct objlist *GRAobj;
   int GRAoid;
-  N_VALUE *GRAinst;
   int GC;
   int PaperWidth, PaperHeight, PaperLandscape;
   char *PaperName, *Palette;
@@ -128,14 +118,16 @@ struct menulocal
   int coordheight, coordwidth, coordx, coordy, coordopen;
   int exwindpi, exwinwidth, exwinheight, exwin_use_external;
   char *fileopendir, *graphloaddir, *expanddir, *coordwin_font, *infowin_font, *file_preview_font;
-  int expand, ignorepath, expandtofullpath, changedirectory, savehistory;
+  int expand, loadpath, expandtofullpath, changedirectory, savehistory;
   int savepath, savewithdata, savewithmerge;
   GtkRecentManager *ngpfilelist;
   int scriptconsole, addinconsole;
-  int statusb, ruler, scrollbar, ctoolbar, ptoolbar, show_cross, showtip, preserve_width;
+  int statusbar, sidebar, ruler, scrollbar, ctoolbar, ptoolbar, show_cross, showtip, preserve_width;
   int hist_size, info_size;
   double bg_r, bg_g, bg_b;
-  int focus_frame_type, use_opacity;
+  int focus_frame_type, use_opacity, select_data;
+  int side_pane1_pos, side_pane2_pos, side_pane3_pos, main_pane_pos, single_window_mode;
+  int file_tab, axis_tab, merge_tab, path_tab, rectangle_tab, arc_tab, mark_tab, text_tab;
 #ifdef WINDOWS
   int emf_dpi;
 #endif
@@ -181,6 +173,8 @@ int mgtkputstderr(const char *s);
 int mgtkprintfstderr(char *fmt, ...);
 int mgtkinterrupt(void);
 int mgtkinputyn(const char *mes);
+int mgtkputstdout(const char *s);
+int mgtkprintfstdout(char *fmt, ...);
 void initwindowconfig(void);
 int mgtkwindowconfig(void);
 void menuadddrawrable(struct objlist *parent, struct narray *drawrable);
@@ -188,5 +182,6 @@ int get_graph_modified(void);
 void set_graph_modified(void);
 void reset_graph_modified(void);
 int menu_save_config(int type);
+void main_window_redraw(void);
 
 #endif
