@@ -29,7 +29,6 @@
 #include <unistd.h>
 #include <math.h>
 
-#include "ngraph.h"
 #include "object.h"
 #include "nstring.h"
 #include "mathfn.h"
@@ -419,6 +418,7 @@ GridDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_pack_start(GTK_BOX(d->vbox), frame, FALSE, FALSE, 4);
 
     add_copy_button_to_box(GTK_WIDGET(d->vbox), G_CALLBACK(grid_copy_clicked), d, "axisgrid");
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
 
   GridDialogSetupItem(wi, d, d->Id);
@@ -756,6 +756,7 @@ SectionDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 4);
 
     gtk_box_pack_start(GTK_BOX(d->vbox), hbox, FALSE, FALSE, 4);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
 
   SectionDialogSetupItem(wi, d);
@@ -959,6 +960,7 @@ CrossDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 4);
 
     gtk_box_pack_start(GTK_BOX(d->vbox), hbox, FALSE, FALSE, 4);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
   CrossDialogSetupItem(wi, d);
 }
@@ -1050,6 +1052,7 @@ ZoomDialogSetup(GtkWidget *wi, void *data, int makewidget)
     item_setup(vbox, w, _("_Zoom:"), TRUE);
     d->zoom_entry = w;
     gtk_box_pack_start(GTK_BOX(d->vbox), vbox, FALSE, FALSE, 4);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
   ZoomDialogSetupItem(wi, d);
 }
@@ -1372,6 +1375,7 @@ scale_tab_create(struct AxisDialog *d)
 
   frame = gtk_frame_new(_("Scale"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
 
 #if GTK_CHECK_VERSION(3, 0, 0)
   parent_box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
@@ -1477,7 +1481,7 @@ baseline_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   d = &dd->base;
 
 #if GTK_CHECK_VERSION(3, 0, 0)
-  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 #else
   hbox = gtk_hbox_new(FALSE, 4);
 #endif
@@ -1508,9 +1512,9 @@ baseline_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Baseline"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
   gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
 
-
 #if GTK_CHECK_VERSION(3, 4, 0)
   table = gtk_grid_new();
 #else
@@ -1539,6 +1543,7 @@ baseline_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Arrow"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_RIGHT);
   gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 
 
@@ -1563,6 +1568,7 @@ baseline_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Wave"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_RIGHT);
   gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
 
   gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
@@ -1699,6 +1705,7 @@ gauge_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Range"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
   gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 
 
@@ -1731,6 +1738,7 @@ gauge_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Style"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
   gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
 
 #if GTK_CHECK_VERSION(3, 0, 0)
@@ -1939,7 +1947,7 @@ numbering_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   d = &dd->numbering;
 
 #if GTK_CHECK_VERSION(3, 0, 0)
-  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
   vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 #else
@@ -1975,6 +1983,7 @@ numbering_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Range"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
   gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 
 
@@ -2004,6 +2013,7 @@ numbering_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Position"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
   gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
 
   gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
@@ -2051,6 +2061,7 @@ numbering_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Format"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_RIGHT);
 
   gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
 
@@ -2206,6 +2217,7 @@ font_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Font"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
 
 #if GTK_CHECK_VERSION(3, 0, 0)
   vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
@@ -2351,6 +2363,7 @@ position_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   frame = gtk_frame_new(_("Position"));
   gtk_container_add(GTK_CONTAINER(frame), table);
+  set_widget_margin(frame, WIDGET_MARGIN_LEFT | WIDGET_MARGIN_RIGHT);
 
 #if GTK_CHECK_VERSION(3, 0, 0)
   vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
@@ -2407,6 +2420,7 @@ AxisDialogSetup(GtkWidget *wi, void *data, int makewidget)
     d->position.tab_id = gtk_notebook_append_page(GTK_NOTEBOOK(notebook), w, label);
 
     gtk_box_pack_start(GTK_BOX(d->vbox), notebook, TRUE, TRUE, 4);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
 
     d->tab = GTK_NOTEBOOK(notebook);
   }
