@@ -30,7 +30,6 @@
 #include <limits.h>
 #include <ctype.h>
 
-#include "ngraph.h"
 #include "object.h"
 #include "mathfn.h"
 #include "nstring.h"
@@ -347,6 +346,7 @@ SelectDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_pack_start(GTK_BOX(d->vbox), hbox, FALSE, FALSE, 4);
 
     gtk_window_set_default_size(GTK_WINDOW(wi), -1, 300);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
 
   list_store_clear(d->list);
@@ -490,6 +490,7 @@ CopyDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_container_add(GTK_CONTAINER(w), swin);
     gtk_box_pack_start(GTK_BOX(d->vbox), w, TRUE, TRUE, 0);
     gtk_window_set_default_size(GTK_WINDOW(wi), -1, 300);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
 
   list_store_clear(d->list);
