@@ -64,6 +64,7 @@ void message_beep(GtkWidget *parent);
 int message_box(GtkWidget *parent, const char *message, const char *title, int yesno);
 int DialogInput(GtkWidget *parent, const char *title, const char *mes, const char *init_str, char **s, int *x, int *y);
 int DialogRadio(GtkWidget *parent, const char *title, const char *caption, struct narray *ary, int *r, int *x, int *y);
+int DialogButton(GtkWidget *parent, const char *title, const char *caption, struct narray *array, int *x, int *y);
 int DialogCheck(GtkWidget *parent, const char *title, const char *caption, struct narray *array, int *r, int *x, int *y);
 int DialogCombo(GtkWidget *parent, const char *title, const char *caption, struct narray *array, int sel, char **r, int *x, int *y);
 int DialogComboEntry(GtkWidget *parent, const char *title, const char *caption, struct narray *array, int sel, char **r, int *x, int *y);
@@ -77,7 +78,7 @@ int nGetOpenFileName(GtkWidget * parent, char *title, char *defext,
 int nGetSaveFileName(GtkWidget * parent, char *title, char *defext,
 		     char **initdir, const char *initfil, char **file,
 		     int overwrite, int chdir);
-void get_window_geometry(GtkWidget *win, gint *x, gint *y, gint *w, gint *h, GdkWindowState *state);
+void get_window_geometry(GtkWidget *win, gint *x, gint *y, gint *w, gint *h);
 void set_sensitivity_by_check_instance(GtkWidget *widget, gpointer user_data);
 int ndialog_run(GtkWidget *dlg);
 #endif
