@@ -18,7 +18,6 @@
 
 #include "dir_defs.h"
 
-#include "ngraph.h"
 #include "object.h"
 #include "ioutil.h"
 #include "shell.h"
@@ -2320,7 +2319,7 @@ create_markpixmap(GtkWidget *win)
 		       robj, inst, output, -1, -1, -1, NULL, local);
 	if (gra >= 0) {
 	  GRAview(gra, 0, 0, MARK_PIX_SIZE, MARK_PIX_SIZE, 0);
-	  GRAlinestyle(gra, 0, NULL, 1, 0, 0, 1000);
+	  GRAlinestyle(gra, 0, NULL, 1, GRA_LINE_CAP_BUTT, GRA_LINE_JOIN_MITER, 1000);
 	  GRAmark(gra, i,
 		  MARK_PIX_SIZE / 2, MARK_PIX_SIZE / 2,
 		  MARK_PIX_SIZE - 4,
@@ -3490,20 +3489,11 @@ toggle_view_cb(GtkToggleAction *action, gpointer data)
     return;
   }
 
-  if (state) {
-    if (w1) {
-      gtk_widget_show(w1);
-    }
-    if (w2) {
-      gtk_widget_show(w2);
-    }
-  } else {
-    if (w1) {
-      gtk_widget_hide(w1);
-    }
-    if (w2) {
-      gtk_widget_hide(w2);
-    }
+  if (w1) {
+    gtk_widget_set_visible(w1, state);
+  }
+  if (w2) {
+    gtk_widget_set_visible(w2, state);
   }
 }
 
@@ -3826,12 +3816,14 @@ create_action_group(struct NgraphActionEntry *entry, int n)
   return action_group;
 }
 
-void
-show_ui_definition(void)
+char *
+get_ui_definition(void)
 {
-  if (NgraphUi) {
-    printfstdout("%s", gtk_ui_manager_get_ui(NgraphUi));
+  if (NgraphUi == NULL) {
+    return NULL;
   }
+
+  return gtk_ui_manager_get_ui(NgraphUi);
 }
 
 int
@@ -4245,7 +4237,7 @@ InputYN(const char *mes)
 {
   int ret;
 
-  ret = message_box((CurrentWindow) ? CurrentWindow : TopLevel, mes, _("Question"), RESPONS_YESNO);
+  ret = message_box(get_current_window(), mes, _("Question"), RESPONS_YESNO);
   UpdateAll2();
   return (ret == IDYES) ? TRUE : FALSE;
 }
