@@ -28,7 +28,6 @@
 #include <string.h>
 #include <unistd.h>
 
-#include "ngraph.h"
 #include "object.h"
 #include "nstring.h"
 #include "ioutil.h"
@@ -154,6 +153,8 @@ MergeDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_pack_start(GTK_BOX(d->vbox), frame, TRUE, TRUE, 4);
 
     add_copy_button_to_box(GTK_WIDGET(d->vbox), G_CALLBACK(MergeDialogCopy), d, "merge");
+
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
   MergeDialogSetupItem(d, TRUE, d->Id);
 }
