@@ -28,7 +28,6 @@
 #include <string.h>
 #include <unistd.h>
 
-#include "ngraph.h"
 #include "nstring.h"
 #include "object.h"
 #include "ioutil.h"
@@ -166,6 +165,7 @@ DriverDialogSetup(GtkWidget *wi, void *data, int makewidget)
     add_widget_to_table(table, w, _("_File:"), TRUE, i++);
 
     gtk_box_pack_start(GTK_BOX(d->vbox), table, FALSE, FALSE, 4);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
 
   combo_box_clear(d->driver);
@@ -257,6 +257,7 @@ OutputDataDialogSetup(GtkWidget *wi, void *data, int makewidget)
 #endif
     item_setup(hbox, w, _("_Div:"), TRUE);
     gtk_box_pack_start(GTK_BOX(d->vbox), hbox, FALSE, FALSE, 4);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
   OutputDataDialogSetupItem(wi, d);
 }
@@ -287,12 +288,15 @@ OutputImageDialogSetupItem(GtkWidget *w, struct OutputImageDialog *d)
 {
   int i;
   GtkWidget *vlabel;
+#if GTK_CHECK_VERSION(3, 0, 0)
+  GtkWidget *window;
+  GtkRequisition minimum_size;
+#endif
 
   vlabel = get_mnemonic_label(d->version);
 
   gtk_label_set_text(GTK_LABEL(vlabel), "");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->use_opacity), FALSE);
-  gtk_widget_set_sensitive(d->version, TRUE); /* fix-me: this code may need to avoid GKT+3 bug. */
 
   combo_box_clear(d->version);
   switch (d->DlgType) {
@@ -301,11 +305,9 @@ OutputImageDialogSetupItem(GtkWidget *w, struct OutputImageDialog *d)
     for (i = 0; PsVersion[i]; i++) {
       combo_box_append_text(d->version, PsVersion[i]);
     }
-    set_widget_sensitivity_with_label(d->dpi, FALSE);
-
-    gtk_widget_set_sensitive(d->version, TRUE);
-    gtk_widget_set_sensitive(vlabel, TRUE);
-    gtk_widget_set_sensitive(d->t2p, TRUE);
+    set_widget_visibility_with_label(d->dpi, FALSE);
+    set_widget_visibility_with_label(d->version, TRUE);
+    gtk_widget_set_visible(d->t2p, TRUE);
 
     gtk_label_set_markup_with_mnemonic(GTK_LABEL(vlabel), _("_PostScript Version:"));
 
@@ -313,28 +315,20 @@ OutputImageDialogSetupItem(GtkWidget *w, struct OutputImageDialog *d)
     combo_box_set_active(d->version, Menulocal.ps_version);
     break;
   case MenuIdOutputPNGFile:
-    combo_box_append_text(d->version, "--------");
-
-    set_widget_sensitivity_with_label(d->dpi, TRUE);
-    gtk_widget_set_sensitive(d->version, FALSE);
-    gtk_widget_set_sensitive(vlabel, FALSE);
-    gtk_widget_set_sensitive(d->t2p, FALSE);
+    set_widget_visibility_with_label(d->dpi, TRUE);
+    set_widget_visibility_with_label(d->version, FALSE);
+    gtk_widget_set_visible(d->t2p, FALSE);
 
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(d->dpi), Menulocal.png_dpi);
-    combo_box_set_active(d->version, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->use_opacity), Menulocal.use_opacity);
 
     break;
   case MenuIdOutputPDFFile:
-    combo_box_append_text(d->version, "--------");
-
-    set_widget_sensitivity_with_label(d->dpi, FALSE);
-    gtk_widget_set_sensitive(d->version, FALSE);
-    gtk_widget_set_sensitive(vlabel, FALSE);
-    gtk_widget_set_sensitive(d->t2p, TRUE);
+    set_widget_visibility_with_label(d->dpi, FALSE);
+    set_widget_visibility_with_label(d->version, FALSE);
+    gtk_widget_set_visible(d->t2p, TRUE);
 
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(d->dpi), 72);
-    combo_box_set_active(d->version, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->use_opacity), Menulocal.use_opacity);
     break;
   case MenuIdOutputSVGFile:
@@ -342,10 +336,9 @@ OutputImageDialogSetupItem(GtkWidget *w, struct OutputImageDialog *d)
       combo_box_append_text(d->version, SvgVersion[i]);
     }
 
-    set_widget_sensitivity_with_label(d->dpi, FALSE);
-    gtk_widget_set_sensitive(d->version, TRUE);
-    gtk_widget_set_sensitive(vlabel, TRUE);
-    gtk_widget_set_sensitive(d->t2p, TRUE);
+    set_widget_visibility_with_label(d->dpi, FALSE);
+    set_widget_visibility_with_label(d->version, TRUE);
+    gtk_widget_set_visible(d->t2p, TRUE);
 
     gtk_label_set_markup_with_mnemonic(GTK_LABEL(vlabel), _("_SVG Version:"));
 
@@ -355,18 +348,21 @@ OutputImageDialogSetupItem(GtkWidget *w, struct OutputImageDialog *d)
     break;
 #ifdef CAIRO_HAS_WIN32_SURFACE
   case MenuIdOutputCairoEMFFile:
-    combo_box_append_text(d->version, "--------");
-
-    set_widget_sensitivity_with_label(d->dpi, TRUE);
-    gtk_widget_set_sensitive(d->version, FALSE);
-    gtk_widget_set_sensitive(vlabel, FALSE);
-    gtk_widget_set_sensitive(d->t2p, TRUE);
-
+    set_widget_visibility_with_label(d->dpi, TRUE);
+    set_widget_visibility_with_label(d->version, FALSE);
+    gtk_widget_set_visible(d->t2p, FALSE);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(d->dpi), Menulocal.emf_dpi);
-    combo_box_set_active(d->version, 0);
     break;
 #endif	/* CAIRO_HAS_WIN32_SURFACE */
   }
+
+#if GTK_CHECK_VERSION(3, 0, 0)
+  window = gtk_widget_get_parent(GTK_WIDGET(d->vbox));
+  if (GTK_IS_WINDOW(window)) {
+    gtk_widget_get_preferred_size(GTK_WIDGET(d->vbox), &minimum_size, NULL);
+    gtk_window_resize(GTK_WINDOW(window), minimum_size.width, minimum_size.height);
+  }
+#endif
 }
 
 static void
@@ -395,6 +391,7 @@ OutputImageDialogSetup(GtkWidget *wi, void *data, int makewidget)
     w = combo_box_create();
     d->version = w;
     item_setup(GTK_WIDGET(d->vbox), w, "", FALSE);
+    gtk_widget_show_all(GTK_WIDGET(d->vbox));
   }
 
   switch (d->DlgType) {
@@ -569,7 +566,7 @@ init_graobj(struct objlist *graobj, int id, char *dev_name, int dev_oid)
     n = arraynum(&(Menulocal.drawrable));
     for (i = 0; i < n; i++) {
       arrayadd2(drawrable,
-		(char **) arraynget(&(Menulocal.drawrable), i));
+		*(char **) arraynget(&(Menulocal.drawrable), i));
     }
   } else {
     drawrable = NULL;
