@@ -425,7 +425,7 @@ findfilename(char *dir,char *sep,char *file)
 {
   char *s;
   int find;
-  struct stat buf;
+  GStatBuf buf;
 
   if ((s=getfilename(dir,sep,file))==NULL) return FALSE;
   if ((naccess(s,R_OK)==0) && (nstat(s,&buf)==0)) {
@@ -803,7 +803,7 @@ nisatty(int fd)
 }
 
 int
-nstat(const gchar *filename, struct stat *buf)
+nstat(const gchar *filename, GStatBuf *buf)
 {
   int r;
   char *tmp;
@@ -816,7 +816,7 @@ nstat(const gchar *filename, struct stat *buf)
     return -1;
   }
 
-  r =  g_stat(tmp, buf);
+  r = g_stat(tmp, buf);
   g_free(tmp);
 
   return r;
