@@ -79,7 +79,7 @@ void set_progress(int pos, char *msg, double fraction);
 int n_mkstemp(const char *dir, char *templ, char **name);
 FILE *n_tmpfile(char **name);
 void n_tmpfile_close(FILE *fp, char *name);
-int nstat(const gchar *filename, struct stat *buf);
+int nstat(const gchar *filename, GStatBuf *buf);
 int naccess(const gchar *filename, int mode);
 int nchdir(const gchar *path);
 char *get_utf8_filename(const char *name);
