@@ -3,6 +3,8 @@
  * 
  */
 
+#include "config.h"
+
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -26,9 +28,6 @@ static struct math_token *get_eoeq(const char *str, const char ** rstr);
 static struct math_token *get_ope(const char *str, const char ** rstr);
 static struct math_token *get_num(const char *str, const char ** rstr);
 
-#define EOEQ_CHAR_OPT '='
-#define EOEQ_CHAR ';'
-
 struct reserved {
   char *name;
   enum MATH_TOKEN_TYPE type;
@@ -96,7 +95,7 @@ math_scanner_get_token(const char *str, const char **rstr)
     str++;
 
   c = str[0];
-  if (c == EOEQ_CHAR_OPT || c == EOEQ_CHAR || c == '\0') {
+  if (c == '\0') {
     return get_eoeq(str, rstr);
   } else  if (isdigit(c) || c == '.') {
     return get_num(str, rstr);
@@ -114,9 +113,7 @@ math_scanner_get_token(const char *str, const char **rstr)
     return get_comma(str, rstr);
   } else if (c == '@') {
     return get_array_prefix(str, rstr);
-  } else if (c == EOEQ_CHAR_OPT || c == EOEQ_CHAR || c == '\0') {
-    return get_eoeq(str, rstr);
-  } 
+  }
 
   return get_unknown(str, rstr);
 }
@@ -221,19 +218,21 @@ get_ope(const char *str,  const char ** rstr)
   int len;
   enum MATH_OPERATOR_TYPE ope;
 
-  tok = create_token(str, MATH_TOKEN_TYPE_OPERATOR);
-  if (tok == NULL) {
-    return NULL;
-  }
-
   ope = math_scanner_check_ope_str(str, &len);
-  if (ope == MATH_OPERATOR_TYPE_UNKNOWN) {
-    tok->type = MATH_TOKEN_TYPE_UNKNOWN;
-    return tok;
+  switch (ope) {
+  case MATH_OPERATOR_TYPE_EOEQ:
+    tok = create_token(str, MATH_TOKEN_TYPE_EOEQ);
+    break;
+  case MATH_OPERATOR_TYPE_UNKNOWN:
+    tok = create_token(str, MATH_TOKEN_TYPE_UNKNOWN);
+    break;
+  default:
+    tok = create_token(str, MATH_TOKEN_TYPE_OPERATOR);
+    if (tok) {
+      tok->data.op = ope;
+    }
   }
 
-  tok->data.op = ope;
-
   *rstr = str + len;
 
   return tok;
@@ -438,8 +437,13 @@ get_dec(const char *str, double *val)
     }
   }
 
+#if HAVE_POWL
   *val = dec * powl(10.0, pow_sign * pow_val) +
     flaction * powl(10.0, pow_sign * pow_val - dec_order);
+#else  /* HAVE_POWL */
+  *val = dec * pow(10.0, pow_sign * pow_val) +
+    flaction * pow(10.0, pow_sign * pow_val - dec_order);
+#endif	/* HAVE_POWL */
 
   return str;
 }
