@@ -26,7 +26,7 @@
 #include <math.h>
 #include <string.h>
 #include <stdio.h>
-#include "ngraph.h"
+#include "common.h"
 #include "object.h"
 #include "mathfn.h"
 #include "gra.h"
@@ -289,7 +289,7 @@ draw_grid_line(struct objlist *obj, int GC,
     if (wid == 0)
       continue;
 
-    GRAlinestyle(GC, snum, sdata, wid, 0, 0, 1000);
+    GRAlinestyle(GC, snum, sdata, wid, GRA_LINE_CAP_BUTT, GRA_LINE_JOIN_MITER, 1000);
 
     x0 = x + (po - a1_prm->min) * a1_pos->len_x / (a1_prm->max - a1_prm->min);
     y0 = y - (po - a1_prm->min) * a1_pos->len_y / (a1_prm->max - a1_prm->min);
@@ -325,7 +325,7 @@ draw_background(struct objlist *obj, N_VALUE *inst, int GC, struct axis_pos *ax,
   pos[6] = pos[0] + ay->len_x;
   pos[7] = pos[1] - ay->len_y;
 
-  GRAdrawpoly(GC, 4, pos, 1);
+  GRAdrawpoly(GC, 4, pos, GRA_FILL_MODE_EVEN_ODD);
 
   return 0;
 }
@@ -366,7 +366,7 @@ agriddraw(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **ar
 
     snprintf(buf, sizeof(buf), "style%d", i + 1);
     _getobj(obj, buf, inst, &st);
-   
+
     gprm.snum[i] = arraynum(st);
     gprm.sdata[i] = arraydata(st);
   }
@@ -434,7 +434,7 @@ static struct objtable agrid[] = {
   {"BB",NINT,NREAD|NWRITE,NULL,NULL,0},
   {"BA",NINT,NREAD|NWRITE,NULL,NULL,0},
   {"draw",NVFUNC,NREAD|NEXEC,agriddraw,"i",0},
-  {"tight",NVFUNC,NREAD|NEXEC,agridtight,NULL,0},
+  {"tight",NVFUNC,NREAD|NEXEC,agridtight,"",0},
 };
 
 #define TBLNUM (sizeof(agrid) / sizeof(*agrid))
