@@ -27,7 +27,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
-#include "ngraph.h"
+#include "common.h"
 #include "object.h"
 #include "gra.h"
 #include "mathfn.h"
@@ -134,7 +134,7 @@ arcdraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 
   if (stroke) {
     GRAcolor(GC,fr,fg,fb, fa);
-    GRAlinestyle(GC, snum, sdata, width, 0, join, miter);
+    GRAlinestyle(GC, snum, sdata, width, GRA_LINE_CAP_BUTT, join, miter);
     GRAcircle(GC, x, y, rx, ry, angle1, angle2,
 	      (close_path) ? ((pieslice) ? 3 : 4) : 0);
   }
