@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <math.h>
 #include <ctype.h>
-#include "ngraph.h"
 #include "object.h"
 #include "oiarray.h"
 
@@ -576,25 +575,25 @@ static struct objtable odarray[] = {
   {"put",NVFUNC,NREAD|NEXEC,darrayput,"id",0},
   {"add",NVFUNC,NREAD|NEXEC,darrayadd,"d",0},
   {"push",NVFUNC,NREAD|NEXEC,darrayadd,"d",0},
-  {"pop",NDFUNC,NREAD|NEXEC,darraypop,NULL,0},
+  {"pop",NDFUNC,NREAD|NEXEC,darraypop,"",0},
   {"ins",NVFUNC,NREAD|NEXEC,darrayins,"id",0},
   {"unshift",NVFUNC,NREAD|NEXEC,darrayunshift,"d",0},
-  {"shift",NDFUNC,NREAD|NEXEC,darrayshift,NULL,0},
+  {"shift",NDFUNC,NREAD|NEXEC,darrayshift,"",0},
   {"del",NVFUNC,NREAD|NEXEC,darraydel,"i",0},
   {"join",NSFUNC,NREAD|NEXEC,darrayjoin,"s",0},
-  {"sort",NVFUNC,NREAD|NEXEC,darraysort,NULL,0},
-  {"rsort",NVFUNC,NREAD|NEXEC,darrayrsort,NULL,0},
-  {"uniq",NVFUNC,NREAD|NEXEC,darrayuniq,NULL,0},
-  {"sum", NDFUNC, NREAD|NEXEC, darray_sum, NULL, 0},
-  {"average", NDFUNC, NREAD|NEXEC, darray_average, NULL, 0},
-  {"sdev", NDFUNC, NREAD|NEXEC, darray_sdev, NULL, 0},
-  {"RMS", NDFUNC, NREAD|NEXEC, darray_rms, NULL, 0},
-  {"min", NDFUNC, NREAD|NEXEC, darray_min, NULL, 0},
-  {"max", NDFUNC, NREAD|NEXEC, darray_max, NULL, 0},
-  {"num", NIFUNC, NREAD|NEXEC, oarray_num, NULL, 0}, 
-  {"seq", NSFUNC, NREAD|NEXEC, oarray_seq, NULL, 0}, 
-  {"rseq", NSFUNC, NREAD|NEXEC, oarray_reverse_seq, NULL, 0}, 
-  {"reverse", NVFUNC, NREAD|NEXEC, oarray_reverse, NULL, 0},
+  {"sort",NVFUNC,NREAD|NEXEC,darraysort,"",0},
+  {"rsort",NVFUNC,NREAD|NEXEC,darrayrsort,"",0},
+  {"uniq",NVFUNC,NREAD|NEXEC,darrayuniq,"",0},
+  {"sum", NDFUNC, NREAD|NEXEC, darray_sum, "", 0},
+  {"average", NDFUNC, NREAD|NEXEC, darray_average, "", 0},
+  {"sdev", NDFUNC, NREAD|NEXEC, darray_sdev, "", 0},
+  {"RMS", NDFUNC, NREAD|NEXEC, darray_rms, "", 0},
+  {"min", NDFUNC, NREAD|NEXEC, darray_min, "", 0},
+  {"max", NDFUNC, NREAD|NEXEC, darray_max, "", 0},
+  {"num", NIFUNC, NREAD|NEXEC, oarray_num, "", 0}, 
+  {"seq", NSFUNC, NREAD|NEXEC, oarray_seq, "", 0}, 
+  {"rseq", NSFUNC, NREAD|NEXEC, oarray_reverse_seq, "", 0}, 
+  {"reverse", NVFUNC, NREAD|NEXEC, oarray_reverse, "", 0},
   {"slice", NVFUNC, NREAD|NEXEC, oarray_slice, "ii", 0},
   {"map", NVFUNC, NREAD|NEXEC, darray_map, "s", 0},
 };
