@@ -33,7 +33,6 @@
 #include <glib.h>
 #include <unistd.h>
 
-#include "ngraph.h"
 #include "object.h"
 #include "nstring.h"
 #include "ntime.h"
@@ -236,7 +235,7 @@ static int
 mergetime(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
   char *file;
-  struct stat buf;
+  GStatBuf buf;
   int style;
 
   g_free(rval->str);
@@ -253,7 +252,7 @@ static int
 mergedate(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
   char *file;
-  struct stat buf;
+  GStatBuf buf;
   int style;
 
   g_free(rval->str);
@@ -293,20 +292,25 @@ mergestore(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
     argv2[1]=NULL;
     if (_exeobj(obj,"time",inst,1,argv2)) return 1;
     _getobj(obj,"date",inst,&date);
+    if(date == NULL) {
+      date = "1-1-1970";
+    }
     _getobj(obj,"time",inst,&time);
+    if(time == NULL) {
+      time = "00:00:00";
+    }
     if ((base=getbasename(file))==NULL) return 1;
     if ((mergelocal->storefd=nfopen(file,"rt"))==NULL) {
       g_free(base);
       return 1;
     }
-    if ((buf=g_malloc(strlen(file)+50))==NULL) {
+    buf = g_strdup_printf("merge::load_data '%s' '%s %s' <<'[EOF]'", base, date, time);
+    g_free(base);
+    if (buf == NULL) {
       fclose(mergelocal->storefd);
       mergelocal->storefd=NULL;
-      g_free(base);
       return 1;
     }
-    sprintf(buf,"merge::load_data '%s' '%s %s' <<'[EOF]'",base,date,time);
-    g_free(base);
     rval->str=buf;
     return 0;
   } else {
@@ -403,15 +407,19 @@ mergestoredum(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **ar
     argv2[1]=NULL;
     if (_exeobj(obj,"time",inst,1,argv2)) return 1;
     _getobj(obj,"date",inst,&date);
+    if(date == NULL) {
+      date = "1-1-1970";
+    }
     _getobj(obj,"time",inst,&time);
+    if(time == NULL) {
+      time = "00:00:00";
+    }
     if ((base=getbasename(file))==NULL) return 1;
-    if ((buf=g_malloc(strlen(file)+50))==NULL) {
-      mergelocal->storefd=NULL;
-      g_free(base);
+    buf = g_strdup_printf("merge::load_dummy '%s' '%s %s'\n", base, date, time);
+    g_free(base);
+    if (buf == NULL) {
       return 1;
     }
-    sprintf(buf,"merge::load_dummy '%s' '%s %s'\n",base,date,time);
-    g_free(base);
     rval->str=buf;
     mergelocal->endstore=TRUE;
     return 0;
@@ -640,9 +648,9 @@ static struct objtable merge[] = {
   {"draw",NVFUNC,NREAD|NEXEC,mergedraw,"i",0},
   {"redraw",NVFUNC,NREAD|NEXEC,mergeredraw,"i",0},
   {"save",NSFUNC,NREAD|NEXEC,pathsave,"sa",0},
-  {"store_data",NSFUNC,NREAD|NEXEC,mergestore,NULL,0},
+  {"store_data",NSFUNC,NREAD|NEXEC,mergestore,"",0},
   {"load_data",NVFUNC,NREAD|NEXEC,mergeload,"s",0},
-  {"store_dummy",NSFUNC,NREAD|NEXEC,mergestoredum,NULL,0},
+  {"store_dummy",NSFUNC,NREAD|NEXEC,mergestoredum,"",0},
   {"load_dummy",NVFUNC,NREAD|NEXEC,mergeloaddum,"s",0},
   {"time",NSFUNC,NREAD|NEXEC,mergetime,"i",0},
   {"date",NSFUNC,NREAD|NEXEC,mergedate,"i",0},
