@@ -28,7 +28,6 @@
 #include <math.h>
 #include <glib.h>
 
-#include "ngraph.h"
 #include "object.h"
 #include "gra.h"
 #include "spline.h"
@@ -497,7 +496,7 @@ draw_stroke(struct objlist *obj, N_VALUE *inst, int GC, int *points2, int *pdata
   sdata = arraydata(style);
 
   GRAcolor(GC, fr, fg, fb, fa);
-  GRAlinestyle(GC, snum, sdata, width, 0, join, miter);
+  GRAlinestyle(GC, snum, sdata, width, GRA_LINE_CAP_BUTT, join, miter);
 
   x0 = points2[0];
   y0 = points2[1];
@@ -521,7 +520,7 @@ draw_stroke(struct objlist *obj, N_VALUE *inst, int GC, int *points2, int *pdata
   }
 
   if (num > 2 && close_path) {
-    GRAdrawpoly(GC, num, pdata, 0);
+    GRAdrawpoly(GC, num, pdata, GRA_FILL_MODE_NONE);
   } else {
     x = points2[0];
     y = points2[1];
@@ -535,13 +534,13 @@ draw_stroke(struct objlist *obj, N_VALUE *inst, int GC, int *points2, int *pdata
   }
 
   if (head == ARROW_POSITION_BEGIN || head == ARROW_POSITION_BOTH) {
-    GRAlinestyle(GC, 0, NULL, 1, 0, join, miter);
-    GRAdrawpoly(GC, 3, ap, 1);
+    GRAlinestyle(GC, 0, NULL, 1, GRA_LINE_CAP_BUTT, join, miter);
+    GRAdrawpoly(GC, 3, ap, GRA_FILL_MODE_EVEN_ODD);
   }
 
   if (head == ARROW_POSITION_END || head == ARROW_POSITION_BOTH) {
-    GRAlinestyle(GC, 0, NULL, 1, 0, join, miter);
-    GRAdrawpoly(GC, 3, ap2, 1);
+    GRAlinestyle(GC, 0, NULL, 1, GRA_LINE_CAP_BUTT, join, miter);
+    GRAdrawpoly(GC, 3, ap2, GRA_FILL_MODE_EVEN_ODD);
   }
 }
 
