@@ -27,7 +27,6 @@
 #include <ctype.h>
 #include <string.h>
 
-#include "ngraph.h"
 #include "object.h"
 #include "oiarray.h"
 
@@ -133,7 +132,7 @@ sarrayput(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
     error(obj, ERROUTBOUND);
     return 1;
   }
-  if (arrayput2(array,&val,num)==NULL) return 1;
+  if (arrayput2(array,val,num)==NULL) return 1;
   return 0;
 }
 
@@ -150,7 +149,7 @@ sarrayadd(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
     return 1;
   }
 
-  if (arrayadd2(array,&val)==NULL) return 1;
+  if (arrayadd2(array,val)==NULL) return 1;
   return 0;
 }
 
@@ -214,7 +213,7 @@ sarrayins(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
     return 1;
   }
 
-  if (arrayins2(array,&val,num)==NULL) return 1;
+  if (arrayins2(array,val,num)==NULL) return 1;
   return 0;
 }
 
@@ -231,7 +230,7 @@ sarrayunshift(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **ar
     return 1;
   }
 
-  if (arrayins2(array, &val, 0)==NULL) {
+  if (arrayins2(array, val, 0)==NULL) {
     return 1;
   }
 
@@ -490,20 +489,20 @@ static struct objtable osarray[] = {
   {"put",NVFUNC,NREAD|NEXEC,sarrayput,"is",0},
   {"add",NVFUNC,NREAD|NEXEC,sarrayadd,"s",0},
   {"push",NVFUNC,NREAD|NEXEC,sarrayadd,"s",0},
-  {"pop",NSFUNC,NREAD|NEXEC,sarraypop,NULL,0},
+  {"pop",NSFUNC,NREAD|NEXEC,sarraypop,"",0},
   {"ins",NVFUNC,NREAD|NEXEC,sarrayins,"is",0},
   {"unshift",NVFUNC,NREAD|NEXEC,sarrayunshift,"s",0},
-  {"shift",NSFUNC,NREAD|NEXEC,sarrayshift,NULL,0},
+  {"shift",NSFUNC,NREAD|NEXEC,sarrayshift,"",0},
   {"del",NVFUNC,NREAD|NEXEC,sarraydel,"i",0},
   {"split",NVFUNC,NREAD|NEXEC,sarraysplit,"s",0},
   {"join",NSFUNC,NREAD|NEXEC,sarrayjoin,"s",0},
   {"sort",NVFUNC,NREAD|NEXEC,sarraysort,"s",0},
   {"rsort",NVFUNC,NREAD|NEXEC,sarrayrsort,"s",0},
-  {"uniq", NSFUNC, NREAD|NEXEC, sarrayuniq, NULL, 0},
-  {"num", NIFUNC, NREAD|NEXEC, oarray_num, NULL, 0},
-  {"seq", NSFUNC, NREAD|NEXEC, oarray_seq, NULL, 0},
-  {"rseq", NSFUNC, NREAD|NEXEC, oarray_reverse_seq, NULL, 0},
-  {"reverse", NVFUNC, NREAD|NEXEC, oarray_reverse, NULL, 0},
+  {"uniq", NSFUNC, NREAD|NEXEC, sarrayuniq, "", 0},
+  {"num", NIFUNC, NREAD|NEXEC, oarray_num, "", 0},
+  {"seq", NSFUNC, NREAD|NEXEC, oarray_seq, "", 0},
+  {"rseq", NSFUNC, NREAD|NEXEC, oarray_reverse_seq, "", 0},
+  {"reverse", NVFUNC, NREAD|NEXEC, oarray_reverse, "", 0},
   {"slice", NVFUNC, NREAD|NEXEC, sarray_slice, "ii", 0},
   {"_local",NPOINTER,0,NULL,NULL,0},
 };
