@@ -145,6 +145,7 @@ shell_proc check_cmd(char *name);
 int check_cpcmd(char *name);
 int init_cmd_tbl(void);
 
+void nsleep(int a);
 int eval_script(const char *script, int security);
 char *addval(struct nshell *nshell,char *name,char *val);
 char *addexp(struct nshell *nshell,char *name);
@@ -170,6 +171,7 @@ int printfconsole(char *fmt,...);
 void ngraphenvironment(struct nshell *nshell);
 int msleep(int ms);
 void set_security(int state);
+int get_security(void);
 void set_environ(void);
 int set_signal(int signal, int flags, void (*handler)(int));
 void set_childhandler(void);
